@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "zig-mode" "20250915.1207"
+(define-package "zig-mode" "20251128.256"
   "A major mode for the Zig programming language."
   '((emacs       "26.1")
     (reformatter "0.6"))
-  :url "https://github.com/zig-lang/zig-mode"
-  :commit "8c1f0bd07e88a443e16e6ffd3abd1d3e76e10f35"
-  :revdesc "8c1f0bd07e88"
+  :url "https://codeberg.org/ziglang/zig-mode"
+  :commit "20e395f940afe1e19e965050b0284ec418d6a9d5"
+  :revdesc "20e395f940af"
   :keywords '("zig" "languages")
   :authors '(("Andrea Orru" . "andreaorru1991@gmail.com")
              ("Andrew Kelley" . "superjoe30@gmail.com"))
